@@ -31,7 +31,7 @@
 //!
 //!- Alternatively [`new_from_memory()`](codes_handle::CodesHandle::new_from_memory) function can be used
 //!to access a file that is already in memory. For example, when file is downloaded from the internet
-//!and does not need to be saved on hard drive. 
+//!and does not need to be saved on hard drive.
 //!The file must be stored in [`bytes::Bytes`](https://docs.rs/bytes/1.1.0/bytes/struct.Bytes.html).
 //!
 //!Data (messages) inside the GRIB file can be accessed using the [`FallibleIterator`](`codes_handle::CodesHandle#impl-FallibleIterator`)
@@ -44,35 +44,46 @@
 //!### Example
 //!
 //!```
-//!// We are reading the mean sea level pressure in Reykjavik
-//!// for 1st June 2021 00:00 UTC (data from ERA5)
+//!// We are reading the mean sea level pressure for 4 gridpoints
+//!// nearest to Reykjavik (64.13N, -21.89E) for 1st June 2021 00:00 UTC 
+//!// from ERA5 Climate Reanalysis
 //!
 //!// Open the GRIB file and create the CodesHandle
 //!# use eccodes::codes_handle::{ProductKind, CodesHandle, KeyedMessage};
+//!# use eccodes::errors::{CodesError};
 //!# use std::path::Path;
-//!# use eccodes::codes_handle::Key::Str;
+//!# use eccodes::codes_handle::KeyType::Str;
 //!# use fallible_iterator::FallibleIterator;
 //!#
+//!# fn main() -> Result<(), CodesError> {
 //!let file_path = Path::new("./data/iceland.grib");
 //!let product_kind = ProductKind::GRIB;
 //!
-//!let handle = CodesHandle::new_from_file(file_path, product_kind).unwrap();
+//!let handle = CodesHandle::new_from_file(file_path, product_kind)?;
 //!
 //!// Use iterator to get a Keyed message with shortName "msl" and typeOfLevel "surface"
 //!// First, filter and collect the messages to get those that we want
-//!let level: Vec<KeyedMessage> = handle
+//!let mut level: Vec<KeyedMessage> = handle
 //!    .filter(|msg| {
 //!
-//!    Ok(msg.read_key("shortName")? == Str(String::from("msl"))
-//!        && msg.read_key("typeOfLevel")? == Str(String::from("surface")))
+//!    Ok(msg.read_key("shortName")?.value == Str("msl".to_string())
+//!        && msg.read_key("typeOfLevel")?.value == Str("surface".to_string()))
 //!    })
-//!    .collect().unwrap();
+//!    .collect()?;
 //!
 //!// Now unwrap and access the first and only element of resulting vector
-//!let level = &level[0];
+//!// Find nearest modifies internal KeyedMessage fields so we need mutable reference
+//!let level = &mut level[0];
 //!
-//!// Read the value of KeyedMessage for the grid point nearest of Reykjavik (64N -22E)
-//!// Not yet implemented
+//!// Get the four nearest gridpoints of Reykjavik
+//!let nearest_gridpoints = level.find_nearest(64.13, -21.89)?;
+//!
+//!// Print value and distance of the nearest gridpoint
+//!println!("value: {}, distance: {}", 
+//!    nearest_gridpoints[3].value, 
+//!    nearest_gridpoints[3].distance);
+//!# Ok(())
+//!# }
 //!```
 //!
 //!### ecCodes installation
@@ -91,7 +102,7 @@
 //!following [this instructions](https://confluence.ecmwf.int/display/ECC/ecCodes+installation).
 //!
 //!Then add the `lib/pkgconfig` directory from your ecCodes installation directory
-//!to the `PKG_CONFIG_PATH` environmental variable. If ecCodes have been compiled 
+//!to the `PKG_CONFIG_PATH` environmental variable. If ecCodes have been compiled
 //!as shared library you will also need to specify `LD_LIBRARY_PATH`.
 //!For example:
 //!
@@ -116,3 +127,5 @@
 pub mod codes_handle;
 pub mod errors;
 mod intermediate_bindings;
+
+pub use fallible_iterator::{FallibleIterator, IntoFallibleIterator, FromFallibleIterator};
